You can use this tool to deploy your application to Shipa.
Shipa is meant and optimized for usage in build CI/CD pipeline.

# Requirements
Shipa required python2 or python3

# Installation
```python
pip install shipa-ci
```

# Usage

```bash
$ shipa-ci -h
Shipa CI tool

optional arguments:
  -h, --help            show this help message and exit
  --directory DIRECTORY
                        directory to deploy (default .)
  --app APP             application name
  --server SERVER       shipa server, for example http://shipa-ci-
                        integration.org:8080
  --email EMAIL         user email
  --password PASSWORD   user password
  --token TOKEN         token
  --verbose             verbose output
  --steps               steps for canary deployment
  --step-interval       single step duration. supported min: m, hour:h, second:s. ex. 1m, 60s, 1h
  --step-weight         step weight
```

There are several required parameters to run shipa-ci:
1) a username and a password to login. 
   Or you could use a token. 
   A token can be generated by Shipa binary: 
    ```bash
   shipa token create ...
    ```
2) an application: --app option 
3) an address of Shipa instance: --server option


